@@ -45,7 +45,7 @@ class ArrayUnmarshaller(PrimitiveUnmarshaller):
     def items_unmarshaller(self) -> "SchemaUnmarshaller":
         # sometimes we don't have any schema i.e. free-form objects
         items_schema = self.schema.get(
-            "items", Spec.from_dict({}, validator=None)
+            "items", Spec.from_dict({}, spec_validator_cls=None)
         )
         return self.schema_unmarshaller.evolve(items_schema)
 
@@ -120,7 +120,7 @@ class ObjectUnmarshaller(PrimitiveUnmarshaller):
             # free-form object
             if additional_properties is True:
                 additional_prop_schema = Spec.from_dict(
-                    {"nullable": True}, validator=None
+                    {"nullable": True}, spec_validator_cls=None
                 )
             # defined schema
             else:
@@ -273,6 +273,14 @@ class SchemaUnmarshaller:
         schema_format = self.find_format(value)
         if schema_format is None:
             return typed
+        # ignore incompatible formats
+        if not (
+            isinstance(value, str)
+            or
+            # Workaround allows bytes for binary and byte formats
+            (isinstance(value, bytes) and schema_format in ["binary", "byte"])
+        ):
+            return typed
         return self.formats_unmarshaller.unmarshal(schema_format, typed)
 
     def get_type_unmarshaller(
@@ -297,17 +305,7 @@ class SchemaUnmarshaller:
         )
 
     def find_format(self, value: Any) -> Optional[str]:
-        for schema in self.iter_valid_schemas(value):
+        for schema in self.schema_validator.iter_valid_schemas(value):
             if "format" in schema:
                 return str(schema.getkey("format"))
         return None
-
-    def iter_valid_schemas(self, value: Any) -> Iterator[Spec]:
-        yield self.schema
-
-        one_of_schema = self.schema_validator.get_one_of_schema(value)
-        if one_of_schema is not None:
-            yield one_of_schema
-
-        yield from self.schema_validator.iter_any_of_schemas(value)
-        yield from self.schema_validator.iter_all_of_schemas(value)
